@@ -18,6 +18,8 @@
 #define CBOR_LENGTH_HUGE        0x1b
 #define CBOR_LENGTH_INDEFINITE  0x1f
 
+#define CBOR_TAG_SHAREABLE 28
+#define CBOR_TAG_SHAREDREF 29
 #define CBOR_TAG_INDIRECTION 22098
 
 #define IS_LITTLE_ENDIAN (BYTEORDER == 0x1234 || BYTEORDER == 0x12345678)
