@@ -1,5 +1,7 @@
 package CBOR::Free::Decoder;
 
+=encoding utf8
+
 =head1 NAME
 
 CBOR::Free::Decoder
@@ -10,6 +12,9 @@ CBOR::Free::Decoder
         2 => sub { DateTime->from_epoch( epoch => shift() ) },
     );
 
+    # Enable shared/circular references:
+    $decoder->preserve_references();
+
 =head1 DESCRIPTION
 
 This class provides an object-oriented interface to L<CBOR::Free>’s
@@ -47,6 +52,16 @@ otherwise ignored.
 
 #----------------------------------------------------------------------
 
+=head2 $enabled_yn = I<OBJ>->preserve_references( [$ENABLE] )
+
+=cut
+
+sub preserve_references {
+    return $_[0]{'_preserve_references'} = (@_ > 1 ? !!$_[1] : 1);
+}
+
+#----------------------------------------------------------------------
+
 =head2 I<OBJ>->set_tag_handlers( %TAG_CALLBACK )
 
 Takes a list of key/value pairs where each key is a tag (i.e., number)
